==> safedelete-1.0.2.tar.gz: safedelete/src/AdminHelper.php <==
<?php

namespace Drupal\safedelete;
use Drupal\Core\Entity\EntityInterface;
use Drupal\menu_link_content\Entity\MenuLinkContent;
use Drupal\node\Entity\Node;
use Drupal\media\Entity\Media;
use Drupal\Core\Link;
use Drupal\Core\Url;


class AdminHelper {


  static public function addMessage($message) {
    \Drupal::messenger()->addMessage($message);
  }


  static public function addToLog($message, $DEBUG = FALSE) {
    //$DEBUG = TRUE;
    if ($DEBUG) {
      \Drupal::logger('safedelete')->notice($message);
    }
  }


  /**
   * Helper function to get all enabled languages, excluding current language.
   */
  static public function getOtherEnabledLanguages() {
    // Get the list of all languages
    $language = \Drupal::languageManager()->getCurrentLanguage();
    $languages = \Drupal::languageManager()->getLanguages();
    $other_languages = array();

    // Add each enabled language, aside from the current language to an array.
    foreach ($languages as $field_language_code => $field_language) {
      if ($field_language_code != $language->getId()) {
        $other_languages[$field_language_code] = $field_language->getName();
      }
    }
    return $other_languages;
  }


  /**
   * Helper function get current language.
   */
  static public function getDefaultLangcode() {
    $language = \Drupal::languageManager()->getDefaultLanguage();
    return $language->getId();
  }


  /**
   * Helper function to get all enabled languages, including the current language.
   */
  static public function getAllEnabledLanguages() {
    // Get the list of all languages
    $language = \Drupal::languageManager()->getCurrentLanguage();
    $languages = \Drupal::languageManager()->getLanguages();
    $other_languages = array();

    // Add each enabled language, aside from the current language to an array.
    foreach ($languages as $field_language_code => $field_language) {
      $other_languages[$field_language_code] = $field_language->getName();
    }
    return $other_languages;
  }


  /**
   *
   * Get the latest revision.
   */
  public static function _latest_revision($nid, &$vid, $langcode) {
    // Change record below might be helpful for future improvements.
    // See change record here: https://www.drupal.org/node/2942013.
    $lang = \Drupal::languageManager()->getCurrentLanguage()->getId();
    if (!isset($langcode)) {
      $langcode = $lang;
    }
    if ($lang != $langcode) {
      $lang = $langcode;
    }
    $latestRevisionResult = \Drupal::entityTypeManager()->getStorage('node')->getQuery()
      ->latestRevision()
      ->condition('nid', $nid, '=')
      ->execute();
    if (count($latestRevisionResult)) {
      $node_revision_id = key($latestRevisionResult);
      if ($node_revision_id == $vid) {
        // There is no pending revision, the current revision is the latest.
        return FALSE;
      }
      $vid = $node_revision_id;
      $latestRevision = \Drupal::entityTypeManager()->getStorage('node')->loadRevision($node_revision_id);
      if ($latestRevision->language()->getId() != $lang && $latestRevision->hasTranslation($lang)) {
        $latestRevision = $latestRevision->getTranslation($lang);
      }
      return $latestRevision;
    }
    return FALSE;
  }


 /**
  * Handle revision sync in all available languages.
  */
  static public function shutdownPostSubmit($entity_id, $state_id, $revision_log, $current_uid) {

    $other_languages = self::getOtherEnabledLanguages();
    foreach ($other_languages as $langcode => $languageName) {
      $entity = self::_latest_revision($entity_id, $vid, $langcode);
      if ($entity->hasTranslation($langcode)) {
        $translation = $entity->getTranslation($langcode);
        $revision = self::prepareNewRevision($translation, $revision_log . " for $langcode", $current_uid);
        $revision->setRevisionTranslationAffected(TRUE);
        $revision->setSyncing(TRUE);
        $revision->set('moderation_state', $state_id);
        $revision->save();
      }
    }
  }


  /**
   * Prepares a new revision of a given entity, if applicable.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   An entity.
   * @param string|\Drupal\Core\StringTranslation\TranslatableMarkup $message
   *   A revision log message to set.
   *
   * @return \Drupal\Core\Entity\EntityInterface
   *   The moderation state for the given entity.
   */
  static public function prepareNewRevision(EntityInterface $entity, $message, $current_uid) {
    $storage = \Drupal::entityTypeManager()->getStorage($entity->getEntityTypeId());
    if ($storage instanceof ContentEntityStorageInterface) {
      $revision = $storage->createRevision($entity);
      if ($revision instanceof RevisionLogInterface) {
        $revision->setRevisionLogMessage($message);
        $revision->setRevisionCreationTime(\Drupal::time()->getRequestTime());
        $revision->setRevisionUserId($current_uid);
      }
      return $revision;
    }
    return $entity;
  }


  /**
   * Safe delete validation and message prep.
   */
  static public function checkMediaReferencesMessage($mid = null, &$bundle = 'image', &$show_button = TRUE, &$markup = '', $type = 'delete', $limit = 20) {
    $action_result = 'deleted';
    if ($type == 'archived') {
      $action_result = $type;
    }
    if (is_null($mid) || empty($mid)) {
      $message = t('Error');
      return;
    }

    $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $media = Media::load($mid);
    $iterate_limit = $limit;
    $result = [];
    $node_storage = \Drupal::entityTypeManager()->getStorage('node');
    $query = \Drupal::entityQuery('node');
    $and1 = $query->orConditionGroup()
      ->condition('body', $media->uuid(), 'CONTAINS');

    $query->condition($and1);
    $nids = $query->execute();
    $entities = [];
    $items_count = 0;
    foreach ($nids as $nid) {
      $entity = \Drupal::entityTypeManager()->getStorage('node')->load($nid);
      $entities[$entity->getEntityTypeId()][$entity->id()] = $entity;
      $entity = \Drupal::entityTypeManager()->getStorage('node')->load($nid);
      $entities[$entity->getEntityTypeId()][$entity->id()] = $entity;
      $items_count++;
    }
    if (empty($nids)) {
      $show_button = TRUE;
    }
    else {
      if (count($entities) > 0) {
        $result = $result + $entities;
      }
    }
    // Begin logic here:
    if (count($result) <= 0) {
      $show_button = TRUE;
      $msg_type = t('Safe Delete verification check status');
      $message_ok = t('Other nodes were searched for uuid or linkit link with the node id in their body content, none were found. <br><b>@TODO for next release:</b> <br>add verification checks for improperly referenced url aliases <br>add checks for other entity types body field values like blocks and paragraphs.<br>  Currently only nodes body fields are checked.');
      $markup = <<<EOT
<div role="contentinfo" aria-labelledby="message-status-title" class="messages-list__item messages messages--warning">
  <div class="messages__header">
    <h2 id="message-status-title" class="messages__title">
      $msg_type
    </h2>
  </div>
  <div class="messages__content">
    $message_ok
  </div>
</div>
EOT;
    }
    if (count($result) > 0) {
      $show_button = FALSE;
      $msg_type = t('Safe Delete verification check status');
      $temp = 'This media is being used in entities and cannot be %action. Please edit the following content first and remove the link:';
      $markup = t($temp, ['%action' => $action_result]) . '<ul>';
      $list_count = 0;
      foreach ($result as $entity_type => $results) {

        foreach ($results as $key => $entity_loaded) {
          if ($iterate_limit <= $list_count) {
            continue;
          }
          $entity_obj = $entity_loaded;
          if (!$entity_obj) {
            continue;
          }
          $slug = str_replace("_", "/", $entity_type);
          $markup .= '<li>' . Link::fromTextAndUrl($entity_obj->label(), Url::fromUri('internal:/' . $slug . '/' . $entity_obj->id()), ['attributes' => ['target' => '_blank']])->toString() . '</li>';
          $list_count++;
        }
      }
      if ($list_count >= $iterate_limit) {
        $markup .= '<li>' . t("... only the first @limit results are displayed.", ['@limit' => $limit]) . '</li>';
      }
      else {
        $markup .= '<li>' . t("... all @list_count results are displayed.", ['@list_count' => $list_count]) . '</li>';
      }
      $markup .= '</ul>';
      $markup = <<<EOT
<div role="contentinfo" aria-labelledby="message-status-title" class="messages-list__item messages messages--warning">
  <div class="messages__header">
    <h2 id="message-status-title" class="messages__title">
      $msg_type
    </h2>
  </div>
  <div class="messages__content">
    $markup
  </div>
</div>
EOT;
    }
  }

  /**
   * Safe delete validation and message prep.
   */
  static public function checkNodeReferencesMessage($nid = null, &$bundle = 'page', &$show_button = TRUE, &$markup = '', $type = 'delete', $limit = 20) {
    $action_result = 'deleted';
    if ($type == 'archived') {
      $action_result = $type;
    }
    if (is_null($nid) || empty($nid)) {
      $message = t('Error');
      return;
    }

    $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $node = Node::load($nid);
    $bundle = $node->getType();
    $iterate_limit = $limit;
    $result = [];
    $node_storage = \Drupal::entityTypeManager()->getStorage('node');
    $query = \Drupal::entityQuery('node');
    $and1 = $query->orConditionGroup()
      ->condition('body', $node->uuid(), 'CONTAINS');

    $query->condition($and1);
    $nids = $query->execute();
    $entities = [];
    $items_count = 0;
    foreach ($nids as $nid) {
      $entity = \Drupal::entityTypeManager()->getStorage('node')->load($nid);
      $entities[$entity->getEntityTypeId()][$entity->id()] = $entity;
      $entity = \Drupal::entityTypeManager()->getStorage('node')->load($nid);
      $entities[$entity->getEntityTypeId()][$entity->id()] = $entity;
      $items_count++;
    }
    if (empty($nids)) {
      $show_button = TRUE;
    }
    else {
      if (count($entities) > 0) {
        $result = $result + $entities;
      }
    }
    // Begin logic here:
    if (count($result) <= 0) {
      $show_button = TRUE;
      $msg_type = t('Safe Delete verification check status');
      $message_ok = t('Other nodes were searched for uuid or linkit link with the node id in their body content, none were found. <br><b>@TODO for next release:</b> <br>add verification checks for improperly referenced url aliases <br>add checks for other entity types body field values like blocks and paragraphs.<br>  Currently only nodes body fields are checked.');
      $markup = <<<EOT
<div role="contentinfo" aria-labelledby="message-status-title" class="messages-list__item messages messages--warning">
  <div class="messages__header">
    <h2 id="message-status-title" class="messages__title">
      $msg_type
    </h2>
  </div>
  <div class="messages__content">
    $message_ok
  </div>
</div>
EOT;
    }
    if (count($result) > 0) {
      $show_button = FALSE;
      $msg_type = t('Safe Delete verification check status');
      $temp = 'This node is being used in entities and cannot be %action. Please edit the following content first and remove the link:';
      $markup = t($temp, ['%action' => $action_result]) . '<ul>';
      $list_count = 0;
      foreach ($result as $entity_type => $results) {

        foreach ($results as $key => $entity_loaded) {
          if ($iterate_limit <= $list_count) {
            continue;
          }
          $entity_obj = $entity_loaded;
          if (!$entity_obj) {
            continue;
          }
          $slug = str_replace("_", "/", $entity_type);
          $markup .= '<li>' . Link::fromTextAndUrl($entity_obj->label(), Url::fromUri('internal:/' . $slug . '/' . $entity_obj->id()), ['attributes' => ['target' => '_blank']])->toString() . '</li>';
          $list_count++;
        }
      }
      if ($list_count >= $iterate_limit) {
        $markup .= '<li>' . t("... only the first @limit results are displayed.", ['@limit' => $limit]) . '</li>';
      }
      else {
        $markup .= '<li>' . t("... all @list_count results are displayed.", ['@list_count' => $list_count]) . '</li>';
      }
      $markup .= '</ul>';
      $markup = <<<EOT
<div role="contentinfo" aria-labelledby="message-status-title" class="messages-list__item messages messages--warning">
  <div class="messages__header">
    <h2 id="message-status-title" class="messages__title">
      $msg_type
    </h2>
  </div>
  <div class="messages__content">
    $markup
  </div>
</div>
EOT;
    }
  }

  /**
   * Search for a menu link.
   */
  static public function hasMenuLink($nid) {
    static::addToLog(__function__);
    $parentMenuLink = NULL;

    $menu_link_manager = \Drupal::service('plugin.manager.menu.link');
    $results = $menu_link_manager->loadLinksByRoute('entity.node.canonical', ['node' => $nid]);

    foreach ($results as $item) {
      $route = '';
      if ($item->getUrlObject()->isRouted()) {
        $route = $item->getUrlObject()->getRouteName();
      }
      if ('entity.node.canonical' == $route && $item->getUrlObject()->isRouted()) {
        $params = $item->getUrlObject()->getRouteParameters();
        $linkNodeId = $params['node'];

        if ($linkNodeId == $nid) {
          return TRUE;
        }
      }
    } // End of foreach.
    return FALSE;
  }


  /**
   * Search the page without being refered in other pages
   */
  static function findOtherLinkedReferences($uuid, $nid) {
    if (empty($nid) || !is_numeric($nid)) {
      return FALSE;
    }
    // @TODO: later,also in case not using linkit also check for /node/{id} links in case NOT using linkit correctly.
    $node_storage = \Drupal::entityTypeManager()->getStorage('node');
    $query = \Drupal::entityQuery('node');
    $and1 = $query->orConditionGroup()
      ->condition('body', 'node/' . $nid . '"', 'CONTAINS');
    $query->condition($and1);
    $nids = $query->execute();
    if (!empty($nids)) {
      return TRUE;
    }
    return FALSE;
  }


  /**
   * Search the page without being refered in other pages
   */
  static function findLinkitReferences($uuid, $nid) {
    if (strlen($uuid) < 15 || empty($uuid)) {
      return FALSE;
    }
    $node_storage = \Drupal::entityTypeManager()->getStorage('node');
    $query = \Drupal::entityQuery('node');
    $and1 = $query->orConditionGroup()
      ->condition('body', $uuid, 'CONTAINS');
    $query->condition($and1);
    $nids = $query->execute();
    if (!empty($nids)) {
      return TRUE;
    }
    return FALSE;
  }

}

==> safedelete-1.0.4.tar.gz: safedelete/src/AdminHelper.php <==
<?php

namespace Drupal\safedelete;
use Drupal\Core\Entity\EntityInterface;
use Drupal\menu_link_content\Entity\MenuLinkContent;
use Drupal\node\Entity\Node;
use Drupal\media\Entity\Media;
use Drupal\Core\Link;
use Drupal\Core\Url;


class AdminHelper {


  static public function addMessage($message) {
    \Drupal::messenger()->addMessage($message);
  }


  static public function addToLog($message, $DEBUG = FALSE) {
    //$DEBUG = TRUE;
    if ($DEBUG) {
      \Drupal::logger('safedelete')->notice($message);
    }
  }


  /**
   * Helper function to get all enabled languages, excluding current language.
   */
  static public function getOtherEnabledLanguages() {
    // Get the list of all languages
    $language = \Drupal::languageManager()->getCurrentLanguage();
    $languages = \Drupal::languageManager()->getLanguages();
    $other_languages = array();

    // Add each enabled language, aside from the current language to an array.
    foreach ($languages as $field_language_code => $field_language) {
      if ($field_language_code != $language->getId()) {
        $other_languages[$field_language_code] = $field_language->getName();
      }
    }
    return $other_languages;
  }


  /**
   * Helper function get current language.
   */
  static public function getDefaultLangcode() {
    $language = \Drupal::languageManager()->getDefaultLanguage();
    return $language->getId();
  }


  /**
   * Helper function to get all enabled languages, including the current language.
   */
  static public function getAllEnabledLanguages() {
    // Get the list of all languages
    $language = \Drupal::languageManager()->getCurrentLanguage();
    $languages = \Drupal::languageManager()->getLanguages();
    $other_languages = array();

    // Add each enabled language, aside from the current language to an array.
    foreach ($languages as $field_language_code => $field_language) {
      $other_languages[$field_language_code] = $field_language->getName();
    }
    return $other_languages;
  }


  /**
   *
   * Get the latest revision.
   */
  public static function _latest_revision($nid, &$vid, $langcode) {
    // Change record below might be helpful for future improvements.
    // See change record here: https://www.drupal.org/node/2942013.
    $lang = \Drupal::languageManager()->getCurrentLanguage()->getId();
    if (!isset($langcode)) {
      $langcode = $lang;
    }
    if ($lang != $langcode) {
      $lang = $langcode;
    }
    $latestRevisionResult = \Drupal::entityTypeManager()->getStorage('node')->getQuery()
      ->condition('nid', $nid, '=')
      ->execute();
    if (count($latestRevisionResult)) {
      $node_revision_id = key($latestRevisionResult);
      if ($node_revision_id == $vid) {
        // There is no pending revision, the current revision is the latest.
        return FALSE;
      }
      $vid = $node_revision_id;
      $latestRevision = \Drupal::entityTypeManager()->getStorage('node')->loadRevision($node_revision_id);
      if ($latestRevision->language()->getId() != $lang && $latestRevision->hasTranslation($lang)) {
        $latestRevision = $latestRevision->getTranslation($lang);
      }
      return $latestRevision;
    }
    return FALSE;
  }


 /**
  * Handle revision sync in all available languages.
  */
  static public function shutdownPostSubmit($entity_id, $state_id, $revision_log, $current_uid) {

    $other_languages = self::getOtherEnabledLanguages();
    foreach ($other_languages as $langcode => $languageName) {
      $entity = self::_latest_revision($entity_id, $vid, $langcode);
      if ($entity->hasTranslation($langcode)) {
        $translation = $entity->getTranslation($langcode);
        $revision = self::prepareNewRevision($translation, $revision_log . " for $langcode", $current_uid);
        $revision->setRevisionTranslationAffected(TRUE);
        $revision->setSyncing(TRUE);
        $revision->set('moderation_state', $state_id);
        $revision->save();
      }
    }
  }


  /**
   * Prepares a new revision of a given entity, if applicable.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   An entity.
   * @param string|\Drupal\Core\StringTranslation\TranslatableMarkup $message
   *   A revision log message to set.
   *
   * @return \Drupal\Core\Entity\EntityInterface
   *   The moderation state for the given entity.
   */
  static public function prepareNewRevision(EntityInterface $entity, $message, $current_uid) {
    $storage = \Drupal::entityTypeManager()->getStorage($entity->getEntityTypeId());
    if ($storage instanceof ContentEntityStorageInterface) {
      $revision = $storage->createRevision($entity);
      if ($revision instanceof RevisionLogInterface) {
        $revision->setRevisionLogMessage($message);
        $revision->setRevisionCreationTime(\Drupal::time()->getRequestTime());
        $revision->setRevisionUserId($current_uid);
      }
      return $revision;
    }
    return $entity;
  }


  /**
   * Safe delete validation and message prep.
   */
  static public function checkMediaReferencesMessage($mid = null, &$bundle = 'image', &$show_button = TRUE, &$markup = '', $type = 'delete', $limit = 20) {
    $action_result = 'deleted';
    if ($type == 'archived') {
      $action_result = $type;
    }
    if (is_null($mid) || empty($mid)) {
      $message = t('Error');
      return;
    }

    $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $media = Media::load($mid);
    $iterate_limit = $limit;
    $result = [];
    $node_storage = \Drupal::entityTypeManager()->getStorage('node');
    $query = \Drupal::entityQuery('node');
    $and1 = $query->orConditionGroup()
      ->condition('body', $media->uuid(), 'CONTAINS');

    $query->condition($and1);
    $nids = $query->latestRevision()->execute();
    $entities = [];
    $items_count = 0;
    foreach ($nids as $nid) {
      $entity = \Drupal::entityTypeManager()->getStorage('node')->load($nid);
      $entities[$entity->getEntityTypeId()][$entity->id()] = $entity;
      $entity = \Drupal::entityTypeManager()->getStorage('node')->load($nid);
      $entities[$entity->getEntityTypeId()][$entity->id()] = $entity;
      $items_count++;
    }
    if (empty($nids)) {
      $show_button = TRUE;
    }
    else {
      if (count($entities) > 0) {
        $result = $result + $entities;
      }
    }
    // Begin logic here:
    if (count($result) <= 0) {
      $show_button = TRUE;
      $msg_type = t('Safe Delete verification check status');
      $message_ok = t('Other nodes were searched for uuid or linkit link with the node id in their body content, none were found. <br><b>@TODO for next release:</b> <br>add verification checks for improperly referenced url aliases <br>add checks for other entity types body field values like blocks and paragraphs.<br>  Currently only nodes body fields are checked.');
      $markup = <<<EOT
<div role="contentinfo" aria-labelledby="message-status-title" class="messages-list__item messages messages--warning">
  <div class="messages__header">
    <h2 id="message-status-title" class="messages__title">
      $msg_type
    </h2>
  </div>
  <div class="messages__content">
    $message_ok
  </div>
</div>
EOT;
    }
    if (count($result) > 0) {
      $show_button = FALSE;
      $msg_type = t('Safe Delete verification check status');
      $temp = 'This media is being used in entities and cannot be %action. Please edit the following content first and remove the link:';
      $markup = t($temp, ['%action' => $action_result]) . '<ul>';
      $list_count = 0;
      foreach ($result as $entity_type => $results) {

        foreach ($results as $key => $entity_loaded) {
          if ($iterate_limit <= $list_count) {
            continue;
          }
          $entity_obj = $entity_loaded;
          if (!$entity_obj) {
            continue;
          }
          $slug = str_replace("_", "/", $entity_type);
          $markup .= '<li>' . Link::fromTextAndUrl($entity_obj->label(), Url::fromUri('internal:/' . $slug . '/' . $entity_obj->id()), ['attributes' => ['target' => '_blank']])->toString() . '</li>';
          $list_count++;
        }
      }
      if ($list_count >= $iterate_limit) {
        $markup .= '<li>' . t("... only the first @limit results are displayed.", ['@limit' => $limit]) . '</li>';
      }
      else {
        $markup .= '<li>' . t("... all @list_count results are displayed.", ['@list_count' => $list_count]) . '</li>';
      }
      $markup .= '</ul>';
      $markup = <<<EOT
<div role="contentinfo" aria-labelledby="message-status-title" class="messages-list__item messages messages--warning">
  <div class="messages__header">
    <h2 id="message-status-title" class="messages__title">
      $msg_type
    </h2>
  </div>
  <div class="messages__content">
    $markup
  </div>
</div>
EOT;
    }
  }


  /**
   * Safe delete validation and message prep.
   */
  static public function checkNodeReferencesMessage($nid = null, &$bundle = 'page', &$show_button = TRUE, &$markup = '', $type = 'delete', $limit = 20) {
    $action_result = 'deleted';
    if ($type == 'archived') {
      $action_result = $type;
    }
    if (is_null($nid) || empty($nid)) {
      $message = t('Error');
      return;
    }

    $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $node = Node::load($nid);
    $bundle = $node->getType();
    $iterate_limit = $limit;
    $result = [];
    $node_storage = \Drupal::entityTypeManager()->getStorage('node');
    $query = \Drupal::entityQuery('node');
    $and1 = $query->orConditionGroup()
      ->condition('body', $node->uuid(), 'CONTAINS');

    $query->condition($and1);
    $nids = $query->latestRevision()->execute();
    $entities = [];
    $items_count = 0;
    foreach ($nids as $nid) {
      $entity = \Drupal::entityTypeManager()->getStorage('node')->load($nid);
      $entities[$entity->getEntityTypeId()][$entity->id()] = $entity;
      $entity = \Drupal::entityTypeManager()->getStorage('node')->load($nid);
      $entities[$entity->getEntityTypeId()][$entity->id()] = $entity;
      $items_count++;
    }
    if (empty($nids)) {
      $show_button = TRUE;
    }
    else {
      if (count($entities) > 0) {
        $result = $result + $entities;
      }
    }
    // Begin logic here:
    if (count($result) <= 0) {
      $show_button = TRUE;
      $msg_type = t('Safe Delete verification check status');
      $message_ok = t('Other nodes were searched for uuid or linkit link with the node id in their body content, none were found. <br><b>@TODO for next release:</b> <br>add verification checks for improperly referenced url aliases <br>add checks for other entity types body field values like blocks and paragraphs.<br>  Currently only nodes body fields are checked.');
      $markup = <<<EOT
<div role="contentinfo" aria-labelledby="message-status-title" class="messages-list__item messages messages--warning">
  <div class="messages__header">
    <h2 id="message-status-title" class="messages__title">
      $msg_type
    </h2>
  </div>
  <div class="messages__content">
    $message_ok
  </div>
</div>
EOT;
    }
    if (count($result) > 0) {
      $show_button = FALSE;
      $msg_type = t('Safe Delete verification check status');
      $temp = 'This node is being used in entities and cannot be %action. Please edit the following content first and remove the link:';
      $markup = t($temp, ['%action' => $action_result]) . '<ul>';
      $list_count = 0;
      foreach ($result as $entity_type => $results) {

        foreach ($results as $key => $entity_loaded) {
          if ($iterate_limit <= $list_count) {
            continue;
          }
          $entity_obj = $entity_loaded;
          if (!$entity_obj) {
            continue;
          }
          $slug = str_replace("_", "/", $entity_type);
          $markup .= '<li>' . Link::fromTextAndUrl($entity_obj->label(), Url::fromUri('internal:/' . $slug . '/' . $entity_obj->id()), ['attributes' => ['target' => '_blank']])->toString() . '</li>';
          $list_count++;
        }
      }
      if ($list_count >= $iterate_limit) {
        $markup .= '<li>' . t("... only the first @limit results are displayed.", ['@limit' => $limit]) . '</li>';
      }
      else {
        $markup .= '<li>' . t("... all @list_count results are displayed.", ['@list_count' => $list_count]) . '</li>';
      }
      $markup .= '</ul>';
      $markup = <<<EOT
<div role="contentinfo" aria-labelledby="message-status-title" class="messages-list__item messages messages--warning">
  <div class="messages__header">
    <h2 id="message-status-title" class="messages__title">
      $msg_type
    </h2>
  </div>
  <div class="messages__content">
    $markup
  </div>
</div>
EOT;
    }
  }

  /**
   * Search for a menu link.
   */
  static public function hasMenuLink($nid) {
    static::addToLog(__function__);
    $parentMenuLink = NULL;

    $menu_link_manager = \Drupal::service('plugin.manager.menu.link');
    $results = $menu_link_manager->loadLinksByRoute('entity.node.canonical', ['node' => $nid]);

    foreach ($results as $item) {
      $route = '';
      if ($item->getUrlObject()->isRouted()) {
        $route = $item->getUrlObject()->getRouteName();
      }
      if ('entity.node.canonical' == $route && $item->getUrlObject()->isRouted()) {
        $params = $item->getUrlObject()->getRouteParameters();
        $linkNodeId = $params['node'];

        if ($linkNodeId == $nid) {
          return TRUE;
        }
      }
    } // End of foreach.
    return FALSE;
  }


  /**
   * Search the page without being refered in other pages
   */
  static function findOtherLinkedReferences($uuid, $nid) {
    if (empty($nid) || !is_numeric($nid)) {
      return FALSE;
    }
    // @TODO: later,also in case not using linkit also check for /node/{id} links in case NOT using linkit correctly.
    $node_storage = \Drupal::entityTypeManager()->getStorage('node');
    $query = \Drupal::entityQuery('node');
    $and1 = $query->orConditionGroup()
      ->condition('body', 'node/' . $nid . '"', 'CONTAINS');
    $query->condition($and1);
    $nids = $query->latestRevision()->execute();
    if (!empty($nids)) {
      return TRUE;
    }
    return FALSE;
  }


  /**
   * Search the page without being refered in other pages
   */
  static function findLinkitReferences($uuid, $nid) {
    if (strlen($uuid) < 15 || empty($uuid)) {
      return FALSE;
    }
    $node_storage = \Drupal::entityTypeManager()->getStorage('node');
    $query = \Drupal::entityQuery('node');
    $and1 = $query->orConditionGroup()
      ->condition('body', $uuid, 'CONTAINS');
    $query->condition($and1);
    $nids = $query->latestRevision()->execute();
    if (!empty($nids)) {
      return TRUE;
    }
    return FALSE;
  }

}
